@@ -5,7 +5,7 @@
 #ifndef CONFIG_H
 #define CONFIG_H
 
-#define PROG_LANGUAGE_ENGLISH	1
+/* #define PROG_LANGUAGE_ENGLISH	1 */
 /* #define PROG_LANGUAGE_SPANISH	2 */
 /* #define PROG_LANGUAGE_FRENCH		3 */
 /* #define PROG_LANGUAGE_GERMAN		4 */
@@ -18,16 +18,17 @@
 /*
  *      Program name:
  */
-#define PROG_NAME	"Search and Rescue"
+#define PROG_NAME		"SearchAndRescue"
+#define PROG_NAME_FULL		"Search and Rescue"
 
 /*
  *      Program version:
  */
-#define PROG_VERSION            "0.8.1"
+#define PROG_VERSION            "0.8.2"
 
 #define PROG_VERSION_MAJOR      0
 #define PROG_VERSION_MINOR      8
-#define PROG_VERSION_RELEASE	1
+#define PROG_VERSION_RELEASE	2
 
 
 /*
@@ -53,6 +54,9 @@ El Uso: SearchAndRescue [options] [GUI_options]\n\
         --software_rendering    Utilice la interpretacin de software en\n\
                                 vez de la interpretacin directa de\n\
                                 hardware.\n\
+        --full_menu_redraw	Always perform full (not partial) menu\n\
+                                redraws (slow but required for certain\n\
+                                accelerated video cards).\n\
         --fullscreen            Utilice el modo repleto de pantalla en\n\
                                 inicio.\n\
         --recorder <address>    Especifica recorder la direccin.\n\
@@ -92,6 +96,9 @@ L'usage: SearchAndRescue [options] [GUI_options]\n\
         --hardware_rendering    Utiliser le matriel direct rend (dfaut).\n\
         --software_rendering    Utiliser rendre de logiciel au lieu de\n\
                                 rendre de matriel direct.\n\
+        --full_menu_redraw      Always perform full (not partial) menu\n\
+                                redraws (slow but required for certain\n\
+                                accelerated video cards).\n\
         --fullscreen            Utiliser le mode cran complet au\n\
                                 dmarrage.\n\
         --recorder <address>    Spcifie l'adresse de recorder.\n\
@@ -134,6 +141,9 @@ Brauch: SearchAndRescue [options] [GUI_options]\n\
                                 (Standardwert).\n\
         --software_rendering    Benutzen Sie Software bergabe statt\n\
                                 direkter Hardware bergabe.\n\
+        --full_menu_redraw      Always perform full (not partial) menu\n\
+                                redraws (slow but required for certain\n\
+                                accelerated video cards).\n\
         --fullscreen            Benutzen Sie vollen Schirm Modus an Start.\n\
         --recorder <address>    Gibt recorder Anschrift an.\n\
         --nosound               Verbinden Sie nicht, Diener an Start zu\n\
@@ -173,6 +183,9 @@ L'uso: SearchAndRescue [options] [GUI_options]\n\
                                 (predefinito).\n\
         --software_rendering    Usare rendere di software invece di\n\
                                 rendere di hardware diretto.\n\
+        --full_menu_redraw      Always perform full (not partial) menu\n\
+                                redraws (slow but required for certain\n\
+                                accelerated video cards).\n\
         --fullscreen            Usare il modo di schermo pieno all'avvio.\n\
         --recorder <address>    Specifica l'indirizzo di recorder.\n\
         --nosound               Non collegare per sembrare il server\n\
@@ -214,6 +227,9 @@ Gebruik: SearchAndRescue [options] [GUI_options]\n\
                                 (standaardwaarde).\n\
         --software_rendering    Gebruik software vertolking in plaats van\n\
                                 rechtstreekze hardware vertolking.\n\
+        --full_menu_redraw      Always perform full (not partial) menu\n\
+                                redraws (slow but required for certain\n\
+                                accelerated video cards).\n\
         --fullscreen            Gebruik vole scherm modus aan start.\n\
         --recorder <address>    Recorder adres specificeert.\n\
         --nosound               Verbind niet om kelner aan start te\n\
@@ -251,6 +267,9 @@ O Uso: SearchAndRescue [options] [GUI_options]\n\
         --hardware_rendering    O uso dirige ferragem deixar (omisso).\n\
         --software_rendering    Use software deixar em vez de ferragem\n\
                                 deixar direto.\n\
+        --full_menu_redraw      Always perform full (not partial) menu\n\
+                                redraws (slow but required for certain\n\
+                                accelerated video cards).\n\
         --fullscreen            Use pleno modo de tela em startup.\n\
         --recorder <address>    Especifica endereo de recorder.\n\
         --nosound               Nao ligue para soar servidor em startup.\n\
@@ -290,6 +309,9 @@ Praksis: SearchAndRescue [options] [GUI_options]\n\
                                 (standardverdi).\n\
         --software_rendering    Bruk programvareytelse i stedet for\n\
                                 direkte jernvareytelse.\n\
+        --full_menu_redraw      Always perform full (not partial) menu\n\
+                                redraws (slow but required for certain\n\
+                                accelerated video cards).\n\
         --fullscreen            Bruk full skjermmodus p oppstarting.\n\
         --recorder <address>    Spesifiserer recorder adresse.\n\
         --nosound               Forbind ikke lyde tjener p oppstarting.\n\
@@ -323,6 +345,9 @@ Usage: SearchAndRescue [options] [GUI_options]\n\
         --hardware_rendering    Use direct hardware rendering (default).\n\
         --software_rendering    Use software rendering instead of direct\n\
                                 hardware rendering.\n\
+        --full_menu_redraw      Always perform full (not partial) menu\n\
+                                redraws (slow but required for certain\n\
+                                accelerated video cards).\n\
         --fullscreen            Use full screen mode at startup.\n\
         --recorder <address>    Specifies recorder address.\n\
         --nosound               Do not connect to sound server at startup.\n\
@@ -432,27 +457,29 @@ to the fullest extent of the law."
 
 
 /*
- *	Maximum length of an object name in bytes (include null terminating
- *	byte):
+ *	Object Name Maximum Length:
  */
 #define SAR_OBJ_NAME_MAX	256
 
 /*
- *	Maximum literal game command (not including argument) length:
+ *	Command Maximum Length:
+ *
+ *	Does not include argument.
  */
 #define SAR_CMD_MAX		80
 
+
 /*
  *      Default directory paths:
  */
 
-/* Local game dir, user's $HOME directory will be prefixed to this. */
+/* Local game dir, user's $HOME directory will be prefixed to this */
 #define SAR_DEF_LOCAL_DATA_DIR  ".SearchAndRescue"
 
-/* Global game dir. */
+/* Global game dir */
 #define SAR_DEF_GLOBAL_DATA_DIR "/usr/share/games/SearchAndRescue"
 
-/* Subdirs, one of each in the local and global game dirs. */
+/* Subdirs, one of each in the local and global game dirs */
 #define SAR_DEF_AIRCRAFTS_DIR		"aircrafts"
 #define SAR_DEF_AUTOMOBILES_DIR		"automobiles"
 #define SAR_DEF_CONTROL_PANELS_DIR	"control_panels"
@@ -463,55 +490,61 @@ to the fullest extent of the law."
 #define SAR_DEF_SOUNDS_DIR		"sounds"
 #define SAR_DEF_TEXTURES_DIR		"textures"
 
-/* Environment variable name that contains the value for the global 
- * directory.
+/*
+ *	Environment Variable Names:
  */
-#define SAR_DEF_ENV_GLOBAL_DIR	"SEARCHANDRESCUE_DATA"
+#define SAR_DEF_ENV_GLOBAL_DIR		"SEARCHANDRESCUE_DATA"
 
 
 /*
- *	Default file paths:
+ *	Default File Paths:
  */
 
-/* Run time preferences file. */
-#define SAR_DEF_RC_FILE			"SearchAndRescue.ini"
+/* Configuration file */
+#define SAR_DEF_OPTIONS_FILE		"SearchAndRescue.ini"
 
-/* Texture reference names and file names list file. */
+/* Texture reference names and file names list file */
 #define SAR_DEF_TEXTURES_FILE		"textures.ini"
 
-/* Human data presets file. */
+/* Actors/Victims/Human Presets file */
 #define SAR_DEF_HUMAN_FILE		"human.ini"
 
-/* Music file references list file. */
+/* Music File References List file */
 #define SAR_DEF_MUSIC_FILE		"music.ini"
 
-/* Weather data presets file. */
+/* Weather Presets file */
 #define SAR_DEF_WEATHER_FILE		"weather.ini"
 
-/* Control panel instruments file, the path
+/* Pilots List file */
+#define SAR_DEF_PLAYERS_FILE		"pilots.ini"
+
+/* Control Panel Instruments file
+ *
  * SAR_DEF_CONTROL_PANELS_DIR/<control_panel_name>/ will be prefixed to
- * this value.
+ * this value
  */
 #define SAR_DEF_INSTRUMENTS_FILE	"instruments.ini"
 
-/* Control panel texture file, the path
+/* Control Panel Texture file
+ *
  * SAR_DEF_CONTROL_PANELS_DIR/<control_panel_name>/ will be prefixed to
- * this value.
+ * this value
  */
 #define SAR_DEF_CONTROL_PANEL_TEX_FILE	"control_panel.tex"
 
-/* Default mission log file. */
+/* Mission Log file */
 #define SAR_DEF_MISSION_LOG_FILE	"mission.log"
 
-/* Icon paths. */
+/* Program Icon file */
 #ifdef __MSW__
 # define SAR_DEF_SAR_ICON_FILE		"SearchAndRescue.ico"
 #else
 # define SAR_DEF_SAR_ICON_FILE		"/usr/share/icons/SearchAndRescue.xpm"
 #endif
 
-/* Standard texture reference names that must be defined in the file
- * SAR_DEF_TEXTURES_FILE.
+/* Standard Texture Reference Names
+ * 
+ * All names here must be defined in the file SAR_DEF_TEXTURES_FILE
  */
 #define SAR_STD_TEXNAME_SUN			"sar_sun"
 #define SAR_STD_TEXNAME_MOON			"sar_moon"
@@ -520,20 +553,23 @@ to the fullest extent of the law."
 #define SAR_STD_TEXNAME_BASKET_END		"sar_basket_end"
 #define SAR_STD_TEXNAME_BASKET_SIDE		"sar_basket_side"
 #define SAR_STD_TEXNAME_EXPLOSION		"sar_explosion"
+#define SAR_STD_TEXNAME_EXPLOSION_IR		"sar_explosion_ir"
 #define SAR_STD_TEXNAME_FIRE			"sar_fire"
+#define SAR_STD_TEXNAME_FIRE_IR			"sar_fire_ir"
 #define SAR_STD_TEXNAME_HELIPAD_PAVED		"sar_helipad_paved"
 #define SAR_STD_TEXNAME_HELIPAD_BARE		"sar_helipad_bare"
 #define SAR_STD_TEXNAME_HELIPAD_BUILDING	"sar_helipad_building"
 #define SAR_STD_TEXNAME_HELIPAD_VEHICLE		"sar_helipad_vehicle"
 #define SAR_STD_TEXNAME_RUNWAY			"sar_runway"
 #define SAR_STD_TEXNAME_ROTOR_WASH		"sar_rotor_wash"
-#define SAR_STD_TEXNAME_SPLASH			"sar_splash"		/* Water splash. */
+#define SAR_STD_TEXNAME_ROTOR_BLADE_BLUR	"sar_rotor_blade_blur"
+#define SAR_STD_TEXNAME_SPLASH			"sar_splash"		/* Water splash */
 #define SAR_STD_TEXNAME_SMOKE_LIGHT		"sar_smoke_light"
 #define SAR_STD_TEXNAME_SMOKE_MEDIUM		"sar_smoke_medium"
 #define SAR_STD_TEXNAME_SMOKE_DARK		"sar_smoke_dark"
 #define SAR_STD_TEXNAME_WATER_RIPPLE		"sar_water_ripple"
 
-/* Menu background images. */
+/* Menu Background Image files */
 #define SAR_DEF_MENU_BGIMG_STANDARD_FILE	"images/menu_std_bg.tga"
 #define SAR_DEF_MENU_BGIMG_FREE_FLIGHT_FILE	"images/menu_free_flight.tga"
 #define SAR_DEF_MENU_BGIMG_MAIN_FILE		"images/menu_main.tga"
@@ -541,7 +577,7 @@ to the fullest extent of the law."
 #define SAR_DEF_MENU_BGIMG_OPTIONS_FILE		"images/menu_options.tga"
 #define SAR_DEF_MENU_BGIMG_PROGRESS_FILE	"images/menu_progress.tga"
 
-/* Mission map icon images. */
+/* Mission Map Icon Image files */
 #define SAR_DEF_MISSION_MAPICON_HELIPAD_FILE	"images/mi_helipad.tga"
 #define SAR_DEF_MISSION_MAPICON_INTERCEPT_FILE	"images/mi_intercept.tga"
 #define SAR_DEF_MISSION_MAPICON_HELICOPTER_FILE	"images/mi_helicopter.tga"
@@ -550,7 +586,7 @@ to the fullest extent of the law."
 #define SAR_DEF_MISSION_MAPICON_CRASH_FILE	"images/mi_crash.tga"
 
 
-/* Sound objects. */
+/* Sound files */
 #define SAR_DEF_SOUND_ERROR		"sounds/error.wav"
 #define SAR_DEF_SOUND_FLIR_ON		"sounds/flir_on.wav"
 #define SAR_DEF_SOUND_FLIR_OFF		"sounds/flir_off.wav"
@@ -578,86 +614,86 @@ to the fullest extent of the law."
 #define SAR_DEF_SOUND_HELICOPTER_ENGINE_SHUTDOWN	\
 					"sounds/helicopter_engine_shutdown.wav"
 
+#define SAR_DEF_SOUND_THUNDER_FAINT	"sounds/thunder_faint.wav"
+#define SAR_DEF_SOUND_THUNDER_MODERATE	"sounds/thunder_moderate.wav"
+#define SAR_DEF_SOUND_THUNDER_LOUD	"sounds/thunder_loud.wav"
+
+
 /*
- *	Standard human preset names, corresonds to human preset data
- *	entries in the file SAR_DEF_HUMAN_FILE.
+ *	Actors/Victims/Human Preset Names:
+ *
+ *	Corresponds to actor preset data entries in the file
+ *	SAR_DEF_HUMAN_FILE
  */
 #define SAR_HUMAN_PRESET_NAME_STANDARD		"standard"
 #define SAR_HUMAN_PRESET_NAME_DIVER		"diver"
 
 
 /*
- *	Comment character (for program's file formats):
+ *	File Format Character Constants:
  */
 #define SAR_COMMENT_CHAR	'#'
-
-/*
- *	Program configuration deliminator character.
- */
 #define SAR_CFG_DELIM_CHAR	'='
 
 
 /*
- *      Show messages for this many milliseconds when a new one is
- *      printed.
+ *	Message Display Interval (in ms):
+ *
+ *	Specifies how long a game message is displayed.
  */
-#define SAR_MESSAGE_SHOW_INT    5000
+#define SAR_MESSAGE_SHOW_INT    5000l
 
 
 /*
- *	Human contact cylendrical bounds (origin at base of feet)
- *	in meters:
+ *	Actors/Victims/Human Cylendrical Contact Bounds (in meters):
+ *
+ *	The origin at base of the feet.
  */
-#define SAR_HUMAN_CONTACT_RADIUS	1.2
-#define SAR_HUMAN_CONTACT_ZMAX		1.8
-#define SAR_HUMAN_CONTACT_ZMIN		0.0
+#define SAR_HUMAN_CONTACT_RADIUS	1.2f
+#define SAR_HUMAN_CONTACT_ZMAX		1.8f
+#define SAR_HUMAN_CONTACT_ZMIN		0.0f
 
 
 /*
- *      Smoke puff respawn interval in milliseconds:
+ *	Smoke Puff Respawn Interval (in ms):
  */
-#define SAR_DEF_SMOKE_SPAWN_INT     3000
+#define SAR_DEF_SMOKE_SPAWN_INT		3000l
 
 /*
- *      Smoke puff life span in milliseconds:
+ *	Smoke Puff Life Span (in ms):
  */
-#define SAR_DEF_SMOKE_LIFE_SPAN     12000
+#define SAR_DEF_SMOKE_LIFE_SPAN		12000l
 
 /*
- *      Explosion frame increment interval in milliseconds:
+ *	Explosion Frame Increment Interval (in ms):
  */
-#define SAR_DEF_EXPLOSION_FRAME_INT	500
+#define SAR_DEF_EXPLOSION_FRAME_INT	500l
 
 /*
- *	Splash frame increment interval in milliseconds:
+ *	Splash Frame Increment Interval (in ms):
  */
-#define SAR_DEF_SPLASH_FRAME_INT	600
+#define SAR_DEF_SPLASH_FRAME_INT	600l
 
 /*
- *	Firy explosions caused by crashes last this long in
- *	milliseconds:
+ *	Sticky Crash Fires Life Span (in ms):
  */
-#define SAR_DEF_CRASH_EXPLOSION_LIFE_SPAN   60000
+#define SAR_DEF_CRASH_EXPLOSION_LIFE_SPAN	60000l
 
 /*
- *	Dropped fuel tanks life span after hitting ground in
- *	milliseconds:
+ *	Dropped Fuel Tanks Life Span (in ms):
+ *
+ *	After hitting ground.
  */
-#define SAR_DEF_FUEL_TANK_LIFE_SPAN	30000
+#define SAR_DEF_FUEL_TANK_LIFE_SPAN	30000l
 
 /*
- *	Lightning life span in milliseconds:
+ *	Actors/Victims/Human Fall Rate (in meters per cycle):
  */
-#define SAR_DEF_LIGHTNING_ON_INT	750
-
-/*
- *	Human object fall rate (in meters per cycle):
- */
-#define SAR_DEF_HUMAN_FALL_RATE		-3.0
+#define SAR_DEF_HUMAN_FALL_RATE		-3.0f
 
 
 /*
- *	Default planetary mean radius (in meters):
+ *	Default Planetary Mean Radius (in meters):
  *
  *	Here we use Earth's mean radius.
  */
@@ -665,45 +701,46 @@ to the fullest extent of the law."
 /* #define SAR_DEF_PLANET_RADIUS	6367470.96322 */
 
 /*
- *	Rotor wash visiblity coefficient:
- */
-#define SAR_DEF_ROTOR_WASH_VIS_COEFF	0.5
-
-/*
- *	Default ground base graphics tiling (in meters):
+ *	Ground Base Tiling (in meters):
  */
 #define SAR_DEF_GROUND_BASE_TILE_WIDTH		400
 #define SAR_DEF_GROUND_BASE_TILE_HEIGHT		400
 #define SAR_DEF_GROUND_BASE_TILE_CLOSE_RANGE	1600
 
-
 /*
- *	Default cloud layer graphics tiling (in meters):
+ *	Cloud Layer Tiling (in meters):
  */
 #define SAR_DEF_CLOUD_TILE_WIDTH		8000
 #define SAR_DEF_CLOUD_TILE_HEIGHT		8000
 #define SAR_DEF_CLOUD_TILE_CLOSE_RANGE		16000
 
-/*
- *	Default hollow surface contact z tolorance (in meters):
- */
-#define SAR_DEF_SURFACE_CONTACT_Z_TOLORANCE	0.05
 
 /*
- *	Default helipad visual range (in meters):
+ *	Rotor Wash Visiblity Coefficient:
+ */
+#define SAR_DEF_ROTOR_WASH_VIS_COEFF		0.5f
+
+
+/*
+ *	Hollow Surface Contact Z Tolorance (in meters):
+ */
+#define SAR_DEF_SURFACE_CONTACT_Z_TOLORANCE	0.05f
+
+
+/*
+ *	Helipad Visual Range (in meters):
  */
 #define SAR_HELIPAD_DEF_RANGE		5000
 
-
 /*
- *	Default human visual range (in meters):
+ *	Actors/Victims/Human Visual Range (in meters):
  */
 #define SAR_HUMAN_DEF_RANGE		1200
 
 /*
- *	Human animation rate (in animation units per cycle):
+ *	Actors/Victims/Human Animation Rate (in animation units per cycle):
  */
-#define SAR_HUMAN_ANIM_RATE	50000
+#define SAR_HUMAN_ANIM_RATE		50000
 
 
 /*
@@ -711,13 +748,49 @@ to the fullest extent of the law."
  *	(for zooming), the bigger this coefficient is the closer the zoom
  *	becomes.
  */
-#define SAR_MAP_DEF_MTOP_COEFF	0.002
+#define SAR_MAP_DEF_MTOP_COEFF		0.002f
 
 
 /*
- *	Keyboard functions help message, array of strings. Each
- *	pair of strings defines one line where the first string is
- *	the key name and the second string is the description.
+ *	Default Temperatures (0.0 to 1.0):
+ */
+#define SAR_DEF_TEMPERATURE		0.6f
+#define SAR_DEF_TEMPERATURE_AIRCRAFT	0.7f
+
+
+/*
+ *	FLIR Color (in r, g, b, a):
+ */
+#define SAR_DEF_FLIR_COLOR		{ 0.0f, 1.0f, 0.0f, 1.0f }
+#define SAR_DEF_FLIR_GL_COLOR		{ 0.0f, 1.0f, 0.0f }
+#define SAR_DEF_FLIR_SKY_COLOR		{ 0.0f, 0.1f, 0.0f, 1.0f }
+#define SAR_DEF_FLIR_SKY_GL_COLOR	{ 0.0f, 0.1f, 0.0f } 
+
+
+/*
+ *	Spotlight Default Attitude (in degrees):
+ */
+#define SAR_DEF_SPOTLIGHT_HEADING	0.0f
+#define SAR_DEF_SPOTLIGHT_PITCH		60.0f
+#define SAR_DEF_SPOTLIGHT_BANK		0.0f
+
+
+/*
+ *	Scoring Points:
+ */
+#define SAR_POINTS_VICTIM_PICKED_UP	50
+#define SAR_POINTS_VICTIM_RESCUED	50
+#define SAR_POINTS_MISSION_ACCOMPLISHED	50
+
+
+/*
+ *	Keyboard Functions Help Message:
+ *
+ *	An array of strings, each are a pair of strings that is
+ *	one line.
+ *
+ *	The first string is the key name and the second is its
+ *	description.
  */
 #if defined(PROG_LANGUAGE_SPANISH)
 #define SAR_KEYS_HELP_MESSAGES  { \
@@ -746,6 +819,7 @@ to the fullest extent of the law."
  "O", "Luces estroboscpicas en/lejos", \
  "L", "Las luces en/lejos", \
  "SHIFT + L", "Marque la luz en/lejos", \
+ "CTRL + L", "La luz central del lugar", \
  "H", "HUD y el texto aclaran", \
  "SHIFT + H", "HUD y el texto oscurecen", \
  "A", "Autopilot/autohover en/lejos", \
@@ -756,11 +830,13 @@ to the fullest extent of the law."
  "SHIFT + F", "Transfiera los tanques externos del combustible", \
  "CTRL + F", "Jetteson los tanques externos del combustible", \
  "S", "Las cuentas/la posicin de la misin", \
- ".", "La rueda frena", \
- "SHIFT + .", "Los frenos de mano", \
+ "PERIOD", "La rueda frena", \
+ "SHIFT + PERIOD", "Los frenos de mano", \
+ "B", "Despliegue/retracta los frenos areos", \
  "R", "Ponga combustible a/la reparacin", \
  "Z", "Ralentcese tiempo", \
  "SHIFT + Z", "Acelere tiempo", \
+ "CTRL + Z", "Normalice la tasa de tiempo", \
  "CTRL + W", "Cambie tiempo", \
  "/", "La orden literal", \
  "CTRL + A", "Basculador de pantano", \
@@ -772,6 +848,7 @@ to the fullest extent of the law."
  "CTRL + F11", "Bascule el modo repleto de pantalla", \
  "CTRL + [", "Disminuya la resolucin", \
  "CTRL + ]", "Aumente la resolucin", \
+ "CTRL + U", "Cambie las unidades", \
  "F9", "Bascule la textura del suelo", \
  "F10", "Bascule de atmsfera", \
  "F11", "Bascule la textura objetiva", \
@@ -810,6 +887,7 @@ to the fullest extent of the law."
  "O", "Sur de d'impulsions utilitaires", \
  "L", "Sur de de lumires", \
  "SHIFT + L", "Apercevoir sur de de lumire", \
+ "CTRL + L", "Centrer la lumire d'endroit", \
  "H", "HUD et le texte s'claircissent", \
  "SHIFT + H", "HUD et le texte assombrissent", \
  "A", "Sur de de pilote automatique autohover", \
@@ -820,11 +898,13 @@ to the fullest extent of the law."
  "SHIFT + F", "Transfrer les rservoirs externes de carburant", \
  "CTRL + F", "Jetteson les rservoirs de carburant externes", \
  "S", "Statut de scores mission", \
- ".", "La roue freine", \
- "SHIFT + .", "Freins  main", \
+ "PERIOD", "La roue freine", \
+ "SHIFT + PERIOD", "Freins  main", \
+ "B", "Dploie/rtracte freins  air comprim", \
  "R", "La Refuel rparation", \
  "Z", "Ralentir le temps", \
  "SHIFT + Z", "Acclrer le temps", \
+ "CTRL + Z", "Normaliser le taux de temps", \
  "CTRL + W", "Changer le temps", \
  "/", "Littral (le tricheur) l'ordre", \
  "CTRL + A", "Le saut de papier (le tricheur) bascule", \
@@ -836,6 +916,7 @@ to the fullest extent of the law."
  "CTRL + F11", "Basculer le mode cran complet", \
  "CTRL + [", "Rsolution de diminution", \
  "CTRL + ]", "Augmenter la rsolution", \
+ "CTRL + U", "Changer des units", \
  "F9", "Basculer le texture de sol", \
  "F10", "Basculer l'atmosphre", \
  "F11", "Bascule le texture d'objet", \
@@ -874,6 +955,7 @@ to the fullest extent of the law."
  "O", "Abtaster auf ab", \
  "L", "Lichter auf ab", \
  "SHIFT + L", "Beflecken Sie Licht auf ab", \
+ "CTRL + L", "Zentrieren Sie Fleck Licht", \
  "H", "HUD und Text hellen auf", \
  "SHIFT + H", "HUD und Text verdunkeln", \
  "A", "Autopilot Autohover auf ab", \
@@ -884,11 +966,13 @@ to the fullest extent of the law."
  "SHIFT + F", "bertragen Sie uerlichen Kraftstoff Tanks", \
  "CTRL + F", "Jetteson uerlicher Kraftstoff Tanks", \
  "S", "Spielergebnisse Mission Status", \
- ".", "Rad bremst", \
- "SHIFT + .", "Parkende Bremsen", \
+ "PERIOD", "Rad bremst", \
+ "SHIFT + PERIOD", "Parkende Bremsen", \
+ "B", "Aufstellen zurckziehen druckluftbremsen", \
  "R", "Tanken Reparatur", \
  "Z", "Verlangsamen Sie Zeit", \
  "SHIFT + Z", "Beschleunigen Zeit", \
+ "CTRL + Z", "Normalisieren Sie Zeit Rate", \
  "CTRL + W", "ndern Sie Wetter", \
  "/", "Wrtlich (Betrger) Befehl", \
  "CTRL + A", "Betrger umschaltet hat verlangsamt", \
@@ -898,8 +982,9 @@ to the fullest extent of the law."
  "CTRL + S", "Gesunde Hhe", \
  "CTRL + M", "Umschaltmusik", \
  "CTRL + F11", "Umschalt voller Schirm Modus", \
- "CTRL + [", "Nehmen Sie Beschlufassung", \
- "CTRL + ]", "Vermehren Sie Beschlufassung", \
+ "CTRL + [", "Nehmen sie beschlufassung", \
+ "CTRL + ]", "Vermehren sie beschlufassung", \
+ "CTRL + U", "ndern sie einheiten", \
  "F9", "Umschalterdgewebe", \
  "F10", "Umschaltatmosphre", \
  "F11", "Kippschalter Objekt Gewebe", \
@@ -937,7 +1022,8 @@ to the fullest extent of the law."
  "D", "La porta apre vicino", \
  "O", "Il su via da di Strobes", \
  "L", "Il su via da di luci", \
- "SHIFT + L", "l su via da di luce di macchia", \
+ "SHIFT + L", "L su via da di luce di macchia", \
+ "CTRL + L", "Concentrare la luce di macchia", \
  "H", "Il brighten di HUD e testo", \
  "SHIFT + H", "HUD ed il testo si oscurano", \
  "A", "Il su via da di pilota automatico autohover", \
@@ -948,11 +1034,13 @@ to the fullest extent of the law."
  "SHIFT + F", "Trasferire i serbatoi di carburante esterni", \
  "CTRL + F", "Il Jetteson i serbatoi di carburante esterni", \
  "S", "Lo stato di punteggi missione", \
- ".", "La ruota frena", \
- "SHIFT + .", "Che i parcheggiando freni", \
+ "PERIOD", "La ruota frena", \
+ "SHIFT + PERIOD", "Che i parcheggiando freni", \
+ "B", "Lo schiera retract freni aerei", \
  "R", "La rifornisce di carburante riparazione", \
  "Z", "Rallentare il tempo", \
  "SHIFT + Z", "Accelerare il tempo", \
+ "CTRL + Z", "Normalizzare il tasso di tempo", \
  "CTRL + W", "Cambiare il tempo", \
  "/", "Letterale (l'imbroglione) il comando", \
  "CTRL + A", "Ha rallentato (l'imbroglione) l'interruttore", \
@@ -964,6 +1052,7 @@ to the fullest extent of the law."
  "CTRL + F11", "Commutare il modo di schermo pieno", \
  "CTRL + [", "Diminuire la risoluzione", \
  "CTRL + ]", "Aumentare la risoluzione", \
+ "CTRL + U", "Cambiare le unit", \
  "F9", "Commutare il tessuto di suolo", \
  "F10", "Commutare il tessuto di atmosfera", \
  "F11", "Commutare il tessuto di oggetto", \
@@ -1002,6 +1091,7 @@ to the fullest extent of the law."
  "O", "Stroboscopen op van", \
  "L", "Lichten op van", \
  "SHIFT + L", "Bevlek licht op van", \
+ "CTRL + L", "Centreer plek licht", \
  "H", "HUD en tekst helderen op", \
  "SHIFT + H", "HUD en tekst verdonkeren", \
  "A", "Automatische piloot autohover op van", \
@@ -1012,11 +1102,13 @@ to the fullest extent of the law."
  "SHIFT + F", "Breng uiterlijke brandstof tanks over", \
  "CTRL + F", "Jetteson uiterlijke brandstof tanks", \
  "S", "Uitslagen missie status", \
- ".", "Wiel remt", \
- "SHIFT + .", "Parkerende remmen.", \
+ "PERIOD", "Wiel remt", \
+ "SHIFT + PERIOD", "Parkerende remmen", \
+ "B", "Inzet terugtrekt lucht remmen", \
  "R", "Refuel herstelling", \
  "Z", "Vertraag tijd", \
  "SHIFT + Z", "Versnel tijd", \
+ "CTRL + Z", "Normaliseer tijd snelheid", \
  "CTRL + W", "Verandeer weer", \
  "/", "Letterlijk (bedrieger) bevel", \
  "CTRL + A", "Slew (bedrieger) knevel", \
@@ -1028,6 +1120,7 @@ to the fullest extent of the law."
  "CTRL + F11", "Druk vole scherm modus", \
  "CTRL + [", "Neem oplossing af", \
  "CTRL + ]", "Neem oplossing toe", \
+ "CTRL + U", "Verandeer eenheden", \
  "F9", "Druk Grondtextuur", \
  "F10", "Druk atmosfeer", \
  "F11", "Druk voorwerp textuur.", \
@@ -1066,6 +1159,7 @@ to the fullest extent of the law."
  "O", "O em fora de Strobes", \
  "L", "O em fora de luzes", \
  "SHIFT + L", "O em fora de luz de mancha", \
+ "CTRL + L", "A luz de mancha de centro", \
  "H", "HUD e texto iluminam", \
  "SHIFT + H", "HUD e texto escurecem", \
  "A", "O em fora de Autopilot autohover", \
@@ -1076,11 +1170,13 @@ to the fullest extent of the law."
  "SHIFT + F", "Transfira tanques externos de combustvel", \
  "CTRL + F", "O Jetteson tanques externos de combustvel", \
  "S", "O estado de contagens misso", \
- ".", "A roda freia", \
- "SHIFT + .", "Que estacionando freios", \
+ "PERIOD", "A roda freia", \
+ "SHIFT + PERIOD", "Que estacionando freios", \
+ "B", "Os freios de ar de instala retrai", \
  "R", "O Refuel repara", \
  "Z", "O tempo de Decelerate", \
  "SHIFT + Z", "Acelere tempo", \
+ "CTRL + Z", "O ndice de tempo de normalize", \
  "CTRL + W", "Mude tempo", \
  "/", "Literal (fraudulento) comando", \
  "CTRL + A", "O Slew (fraudulento) toggle", \
@@ -1092,6 +1188,7 @@ to the fullest extent of the law."
  "CTRL + F11", "O Toggle pleno modo de tela", \
  "CTRL + [", "Diminua resoluo", \
  "CTRL + ]", "Aumente resoluo", \
+ "CTRL + U", "Mude unidades", \
  "F9", "O Toggle textura moda", \
  "F10", "O Toggle atmosfera", \
  "F11", "O Toggle textura de objeto", \
@@ -1130,6 +1227,7 @@ to the fullest extent of the law."
  "O", "Stroboskoper p av", \
  "L", "Lys p av", \
  "SHIFT + L", "Identifiser lys p av", \
+ "CTRL + L", "Sentrer flekklys", \
  "H", "HUD og tekst klarner", \
  "SHIFT + H", "HUD og tekst mrklegger", \
  "A", "Autopilot autohover p av", \
@@ -1140,11 +1238,13 @@ to the fullest extent of the law."
  "SHIFT + F", "Overfr ytre drivstofftanker", \
  "CTRL + F", "Jetteson ytre drivstofftanker", \
  "S", "Stillinger misjon status", \
- ".", "Hjul bremser", \
- "SHIFT + .", "Parkerende bremser", \
+ "PERIOD", "Hjul bremser", \
+ "SHIFT + PERIOD", "Parkerende bremser", \
+ "B", "Deploy/trekke tilbake luftbremser", \
  "R", "Bunkrer reparasjon", \
  "Z", "Decelerate tid", \
  "SHIFT + Z", "Akselerer tid", \
+ "CTRL + Z", "Normaliser tidsrate", \
  "CTRL + W", "Forandr vr", \
  "/", "Ordrett (snyter) kommando", \
  "CTRL + A", "Slew (snyter) omkopler", \
@@ -1156,6 +1256,7 @@ to the fullest extent of the law."
  "CTRL + F11", "Omkoplings full skjermmodus", \
  "CTRL + [", "Mink resolusjon", \
  "CTRL + ]", "k resolusjon", \
+ "CTRL + U", "Forandr enheter", \
  "F9", "Omkoplings malt tekstur", \
  "F10", "Omkoplingsatmosfre", \
  "F11", "Toggle objekttekstur", \
@@ -1194,6 +1295,7 @@ to the fullest extent of the law."
  "O", "Strobes on/off", \
  "L", "Lights on/off", \
  "SHIFT + L", "Spot light on/off", \
+ "CTRL + L", "Center spot light", \
  "H", "HUD and text brighten", \
  "SHIFT + H", "HUD and text darken", \
  "A", "Autopilot/autohover on/off", \
@@ -1204,14 +1306,16 @@ to the fullest extent of the law."
  "SHIFT + F", "Transfer external fuel tanks", \
  "CTRL + F", "Jetteson external fuel tanks", \
  "S", "Scores/mission status", \
- ".", "Wheel brakes", \
- "SHIFT + .", "Parking brakes", \
+ "PERIOD", "Wheel brakes", \
+ "SHIFT + PERIOD", "Parking brakes", \
+ "B", "Deploy/retract air brakes", \
  "R", "Refuel, repair, and drop off passengers", \
  "Z", "Decelerate time (slow-motion)", \
  "SHIFT + Z", "Accelerate time (compress)", \
+ "CTRL + Z", "Normalize time rate", \
  "CTRL + W", "Change weather", \
- "/", "Literal (cheat) command", \
- "CTRL + A", "Slew (cheat) toggle", \
+ "/", "Literal command", \
+ "CTRL + A", "Slew/flight toggle", \
  "T", "Increase time of day", \
  "SHIFT + T", "Decrease time of day", \
  "CTRL + D", "Flight physics", \
@@ -1220,6 +1324,7 @@ to the fullest extent of the law."
  "CTRL + F11", "Toggle full screen mode", \
  "CTRL + [", "Decrease resolution", \
  "CTRL + ]", "Increase resolution", \
+ "CTRL + U", "Change units", \
  "F9", "Toggle ground texture", \
  "F10", "Toggle atmosphere", \
  "F11", "Toggle object texture", \
@@ -1262,11 +1367,14 @@ No such object"
 Passengers"
 
 
-#define SAR_MESG_HOIST_END_SELECT_DIVER		"\
-Hoist Rope Deployment: Diver Ready"
-
 #define SAR_MESG_HOIST_END_SELECT_BASKET	"\
-Hoist Rope Deploymeny: Basket Ready"
+Hoist Deploymeny: Basket"
+
+#define SAR_MESG_HOIST_END_SELECT_DIVER		"\
+Hoist Deployment: Diver"
+
+#define SAR_MESG_HOIST_END_SELECT_HOOK		"\
+Hoist Deployment: Hook"
 
 #define SAR_MESG_HOIST_END_SELECT_ROPE_OUT	"\
 Hoist rope is currently deployed"
@@ -1336,7 +1444,7 @@ STALL"
 #define SAR_MESG_OVERSPEED			"\
 OVERSPEED"
 #define SAR_MESG_TIME_ACCELERATION		"\
-TIME ACCELERQTION"
+TIME ACCELERATION"
 #define SAR_MESG_SLOW_MOTION			"\
 SLOW MOTION"
 
@@ -1344,7 +1452,7 @@ SLOW MOTION"
 Time of day"
 
 #define SAR_MESG_CANNOT_CLOSE_DOOR_BASKET	"\
-Cannot close door, basket is still out!"
+Unable to close door, the hoist is still deployed"
 
 
 #define SAR_MESG_CRASH_BANNER			"\
@@ -1405,10 +1513,10 @@ Flight Physics: Realistic"
 No reserved fuel to transfer"
 
 /* %.0f is replaced with the amount of reserved fuel transfered from
- * reserved tanks to main tanks in lbs.
+ * reserved tanks to main tanks and %s is replaced with the units
  */
 #define SAR_MESG_RESERVE_FUEL_TRANSFERED	"\
-Transfered %.0f lbs of fuel"
+Transfered %.0f %s of fuel"
 
 
 #define SAR_MESG_NOT_REFUELABLE			"\
